Class: Google::Apis::CloudsearchV1::MapInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Geo information used for rendering a map that shows the user's work location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MapInfo

Returns a new instance of MapInfo.



4701
4702
4703
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latFloat

Latitude in degrees Corresponds to the JSON property lat

Returns:

  • (Float)


4676
4677
4678
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4676

def lat
  @lat
end

#location_urlGoogle::Apis::CloudsearchV1::SafeUrlProto

Message containing a string that is safe to use in URL contexts in DOM APIs and HTML documents, where the URL context does not refer to a resource that loads code. Corresponds to the JSON property locationUrl



4683
4684
4685
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4683

def location_url
  @location_url
end

#longFloat

Longitude in degrees Corresponds to the JSON property long

Returns:

  • (Float)


4688
4689
4690
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4688

def long
  @long
end

#map_tileArray<Google::Apis::CloudsearchV1::MapTile>

MapTiles for the area around a user's work location Corresponds to the JSON property mapTile



4693
4694
4695
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4693

def map_tile
  @map_tile
end

#zoomFixnum

The zoom level of the map. A constant zoom value of 18 is used for now to match the zoom of the map shown on a Moma Teams Profile page Corresponds to the JSON property zoom

Returns:

  • (Fixnum)


4699
4700
4701
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4699

def zoom
  @zoom
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4706
4707
4708
4709
4710
4711
4712
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4706

def update!(**args)
  @lat = args[:lat] if args.key?(:lat)
  @location_url = args[:location_url] if args.key?(:location_url)
  @long = args[:long] if args.key?(:long)
  @map_tile = args[:map_tile] if args.key?(:map_tile)
  @zoom = args[:zoom] if args.key?(:zoom)
end