Class: Google::Apis::CloudsearchV1::NamedProperty

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

A typed name-value pair for structured data. The type of the value should be the same as the registered type for the name property in the object definition of objectType.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedProperty

Returns a new instance of NamedProperty.



4962
4963
4964
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boolean_valueBoolean Also known as: boolean_value?

Corresponds to the JSON property booleanValue

Returns:

  • (Boolean)


4912
4913
4914
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4912

def boolean_value
  @boolean_value
end

#date_valuesGoogle::Apis::CloudsearchV1::DateValues

List of date values. Corresponds to the JSON property dateValues



4918
4919
4920
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4918

def date_values
  @date_values
end

#double_valuesGoogle::Apis::CloudsearchV1::DoubleValues

List of double values. Corresponds to the JSON property doubleValues



4923
4924
4925
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4923

def double_values
  @double_values
end

#enum_valuesGoogle::Apis::CloudsearchV1::EnumValues

List of enum values. Corresponds to the JSON property enumValues



4928
4929
4930
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4928

def enum_values
  @enum_values
end

#html_valuesGoogle::Apis::CloudsearchV1::HtmlValues

List of html values. Corresponds to the JSON property htmlValues



4933
4934
4935
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4933

def html_values
  @html_values
end

#integer_valuesGoogle::Apis::CloudsearchV1::IntegerValues

List of integer values. Corresponds to the JSON property integerValues



4938
4939
4940
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4938

def integer_values
  @integer_values
end

#nameString

The name of the property. This name should correspond to the name of the property that was registered for object definition in the schema. The maximum allowable length for this property is 256 characters. Corresponds to the JSON property name

Returns:

  • (String)


4945
4946
4947
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4945

def name
  @name
end

#object_valuesGoogle::Apis::CloudsearchV1::ObjectValues

List of object values. Corresponds to the JSON property objectValues



4950
4951
4952
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4950

def object_values
  @object_values
end

#text_valuesGoogle::Apis::CloudsearchV1::TextValues

List of text values. Corresponds to the JSON property textValues



4955
4956
4957
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4955

def text_values
  @text_values
end

#timestamp_valuesGoogle::Apis::CloudsearchV1::TimestampValues

List of timestamp values. Corresponds to the JSON property timestampValues



4960
4961
4962
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4960

def timestamp_values
  @timestamp_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4967
4968
4969
4970
4971
4972
4973
4974
4975
4976
4977
4978
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4967

def update!(**args)
  @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
  @date_values = args[:date_values] if args.key?(:date_values)
  @double_values = args[:double_values] if args.key?(:double_values)
  @enum_values = args[:enum_values] if args.key?(:enum_values)
  @html_values = args[:html_values] if args.key?(:html_values)
  @integer_values = args[:integer_values] if args.key?(:integer_values)
  @name = args[:name] if args.key?(:name)
  @object_values = args[:object_values] if args.key?(:object_values)
  @text_values = args[:text_values] if args.key?(:text_values)
  @timestamp_values = args[:timestamp_values] if args.key?(:timestamp_values)
end