Class: Google::Apis::CloudsearchV1::ObjectDefinition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

The definition for an object within a data source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObjectDefinition

Returns a new instance of ObjectDefinition.



5006
5007
5008
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name for the object, which then defines its type. Item indexing requests should set the objectType field equal to this value. For example, if name is Document, then indexing requests for items of type Document should set objectType equal to Document. Each object definition must be uniquely named within a schema. The name must start with a letter and can only contain letters (A-Z, a-z) or numbers (0-9). The maximum length is 256 characters. Corresponds to the JSON property name

Returns:

  • (String)


4993
4994
4995
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4993

def name
  @name
end

#optionsGoogle::Apis::CloudsearchV1::ObjectOptions

The options for an object. Corresponds to the JSON property options



4998
4999
5000
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4998

def options
  @options
end

#property_definitionsArray<Google::Apis::CloudsearchV1::PropertyDefinition>

The property definitions for the object. The maximum number of elements is 1000. Corresponds to the JSON property propertyDefinitions



5004
5005
5006
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5004

def property_definitions
  @property_definitions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5011
5012
5013
5014
5015
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5011

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @property_definitions = args[:property_definitions] if args.key?(:property_definitions)
end