Class: Google::Apis::CloudsearchV1::ObjectOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

The options for an object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObjectOptions

Returns a new instance of ObjectOptions.



5084
5085
5086
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_optionsGoogle::Apis::CloudsearchV1::ObjectDisplayOptions

The display options for an object. Corresponds to the JSON property displayOptions



5058
5059
5060
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5058

def display_options
  @display_options
end

#freshness_optionsGoogle::Apis::CloudsearchV1::FreshnessOptions

Indicates which freshness property to use when adjusting search ranking for an item. Fresher, more recent dates indicate higher quality. Use the freshness option property that best works with your data. For fileshare documents, last modified time is most relevant. For calendar event data, the time when the event occurs is a more relevant freshness indicator. In this way, calendar events that occur closer to the time of the search query are considered higher quality and ranked accordingly. Corresponds to the JSON property freshnessOptions



5069
5070
5071
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5069

def freshness_options
  @freshness_options
end

#suggestion_filtering_operatorsArray<String>

Operators that can be used to filter suggestions. For Suggest API, only operators mentioned here will be honored in the FilterOptions. Only TEXT and ENUM operators are supported. NOTE: "objecttype", "type" and "mimetype" are already supported. This property is to configure schema specific operators. Even though this is an array, only one operator can be specified. This is an array for future extensibility. Operators mapping to multiple properties within the same object are not supported. If the operator spans across different object types, this option has to be set once for each object definition. Corresponds to the JSON property suggestionFilteringOperators

Returns:

  • (Array<String>)


5082
5083
5084
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5082

def suggestion_filtering_operators
  @suggestion_filtering_operators
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5089
5090
5091
5092
5093
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5089

def update!(**args)
  @display_options = args[:display_options] if args.key?(:display_options)
  @freshness_options = args[:freshness_options] if args.key?(:freshness_options)
  @suggestion_filtering_operators = args[:suggestion_filtering_operators] if args.key?(:suggestion_filtering_operators)
end