Class: Google::Apis::CloudsearchV1::Person

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Object to represent a person.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Person

Returns a new instance of Person.



5274
5275
5276
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_addressesArray<Google::Apis::CloudsearchV1::EmailAddress>

The person's email addresses Corresponds to the JSON property emailAddresses



5244
5245
5246
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5244

def email_addresses
  @email_addresses
end

#nameString

The resource name of the person to provide information about. See People.get from the Google People API. Corresponds to the JSON property name

Returns:

  • (String)


5251
5252
5253
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5251

def name
  @name
end

#obfuscated_idString

Obfuscated ID of a person. Corresponds to the JSON property obfuscatedId

Returns:

  • (String)


5256
5257
5258
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5256

def obfuscated_id
  @obfuscated_id
end

#person_namesArray<Google::Apis::CloudsearchV1::Name>

The person's name Corresponds to the JSON property personNames



5261
5262
5263
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5261

def person_names
  @person_names
end

#phone_numbersArray<Google::Apis::CloudsearchV1::PhoneNumber>

The person's phone numbers Corresponds to the JSON property phoneNumbers



5266
5267
5268
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5266

def phone_numbers
  @phone_numbers
end

#photosArray<Google::Apis::CloudsearchV1::Photo>

A person's read-only photo. A picture shown next to the person's name to help others recognize the person in search results. Corresponds to the JSON property photos



5272
5273
5274
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5272

def photos
  @photos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5279
5280
5281
5282
5283
5284
5285
5286
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5279

def update!(**args)
  @email_addresses = args[:email_addresses] if args.key?(:email_addresses)
  @name = args[:name] if args.key?(:name)
  @obfuscated_id = args[:obfuscated_id] if args.key?(:obfuscated_id)
  @person_names = args[:person_names] if args.key?(:person_names)
  @phone_numbers = args[:phone_numbers] if args.key?(:phone_numbers)
  @photos = args[:photos] if args.key?(:photos)
end