Class: Google::Apis::CloudsearchV1::PersonCore

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Information for rendering a person. NEXT ID: 37

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PersonCore

Returns a new instance of PersonCore.



5505
5506
5507
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#address_me_asString

Instructions for how to address this person (e.g. custom pronouns). For google. com this is a set of pronouns from a defined list of options. Corresponds to the JSON property addressMeAs

Returns:

  • (String)


5297
5298
5299
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5297

def address_me_as
  @address_me_as
end

#admin_toArray<Google::Apis::CloudsearchV1::PersonCore>

People the profile owner is an admin to. Note that not all fields of these PersonCores will be set, in particular, relationships will be empty. Corresponds to the JSON property adminTo



5303
5304
5305
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5303

def admin_to
  @admin_to
end

#adminsArray<Google::Apis::CloudsearchV1::PersonCore>

The profile owner's admins in no particular order. Note that not all fields of these PersonCores will be set, in particular, relationships will be empty. Corresponds to the JSON property admins



5309
5310
5311
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5309

def admins
  @admins
end

#availability_statusString

Corresponds to the JSON property availabilityStatus

Returns:

  • (String)


5314
5315
5316
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5314

def availability_status
  @availability_status
end

#birthdayGoogle::Apis::CloudsearchV1::Date

Represents a whole calendar date, for example a date of birth. The time of day and time zone are either specified elsewhere or are not significant. The date is relative to the Proleptic Gregorian Calendar. The date must be a valid calendar date between the year 1 and 9999. Corresponds to the JSON property birthday



5323
5324
5325
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5323

def birthday
  @birthday
end

#calendar_urlGoogle::Apis::CloudsearchV1::SafeUrlProto

Message containing a string that is safe to use in URL contexts in DOM APIs and HTML documents, where the URL context does not refer to a resource that loads code. Corresponds to the JSON property calendarUrl



5330
5331
5332
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5330

def calendar_url
  @calendar_url
end

#chat_urlGoogle::Apis::CloudsearchV1::SafeUrlProto

Message containing a string that is safe to use in URL contexts in DOM APIs and HTML documents, where the URL context does not refer to a resource that loads code. Corresponds to the JSON property chatUrl



5337
5338
5339
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5337

def chat_url
  @chat_url
end

#cost_centerString

Person's cost center as a string, e.g. "926: Googler Apps". Corresponds to the JSON property costCenter

Returns:

  • (String)


5342
5343
5344
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5342

def cost_center
  @cost_center
end

#departmentString

The person's Organization department, e.g. "People Operations". For google.com this is usually called "area". Corresponds to the JSON property department

Returns:

  • (String)


5348
5349
5350
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5348

def department
  @department
end

#direct_reportsArray<Google::Apis::CloudsearchV1::PersonCore>

A subset of the profile owner's direct reports. The number of entities here may be less than total_direct_reports_count, because typically ProfileResponse does not include all the person's reports, if there are too many to retrieve efficiently. Note that not all fields of these PersonCores will be set, in particular, relationships will be empty. Corresponds to the JSON property directReports



5357
5358
5359
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5357

def direct_reports
  @direct_reports
end

#dotted_line_managersArray<Google::Apis::CloudsearchV1::PersonCore>

The profile owner's direct dotted line managers in no particular order. Note that not all fields of these PersonCores will be set, in particular, relationships will be empty. Corresponds to the JSON property dottedLineManagers



5364
5365
5366
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5364

def dotted_line_managers
  @dotted_line_managers
end

#dotted_line_reportsArray<Google::Apis::CloudsearchV1::PersonCore>

A subset of the profile owner's dotted-line reports. The number of entities here may be less than total_dlr_count. Note that not all fields of these PersonCores will be set, in particular, relationships will be empty. Corresponds to the JSON property dottedLineReports



5371
5372
5373
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5371

def dotted_line_reports
  @dotted_line_reports
end

#emailsArray<String>

E-mail addresses of the person. The primary or preferred email should be first. Corresponds to the JSON property emails

Returns:

  • (Array<String>)


5376
5377
5378
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5376

def emails
  @emails
end

#employee_idString

Person's employee number (external ID of type "organization") For google.com this is the badge number (e.g. 2 for Larry Page). Corresponds to the JSON property employeeId

Returns:

  • (String)


5382
5383
5384
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5382

def employee_id
  @employee_id
end

#fingerprintString

A fingerprint used by PAPI to reliably determine if a resource has changed Externally it is used as part of the etag. Corresponds to the JSON property fingerprint

Returns:

  • (String)


5388
5389
5390
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5388

def fingerprint
  @fingerprint
end

#fte_permilleFixnum

Full-time equivalent (in ‰) (e.g. 800 for a person who's working 80%). Corresponds to the JSON property ftePermille

Returns:

  • (Fixnum)


5393
5394
5395
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5393

def fte_permille
  @fte_permille
end

#geo_locationGoogle::Apis::CloudsearchV1::MapInfo

Geo information used for rendering a map that shows the user's work location. Corresponds to the JSON property geoLocation



5398
5399
5400
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5398

def geo_location
  @geo_location
end

#gmail_urlString

Corresponds to the JSON property gmailUrl

Returns:

  • (String)


5403
5404
5405
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5403

def gmail_url
  @gmail_url
end

#job_titleString

Profile owner's job title (e.g. "Software Engineer"). For google.com this is the Workday preferred job title. Corresponds to the JSON property jobTitle

Returns:

  • (String)


5409
5410
5411
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5409

def job_title
  @job_title
end

#keyword_typesArray<String>

List of keys to use from the map 'keywords'. Corresponds to the JSON property keywordTypes

Returns:

  • (Array<String>)


5414
5415
5416
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5414

def keyword_types
  @keyword_types
end

#keywordsHash<String,String>

Custom keywords the domain admin has added. Corresponds to the JSON property keywords

Returns:

  • (Hash<String,String>)


5419
5420
5421
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5419

def keywords
  @keywords
end

Custom links the profile owner has added. Corresponds to the JSON property links



5424
5425
5426
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5424

def links
  @links
end

#locationString

Detailed desk location within the company. For google.com this is the desk location code (e.g. "DE-MUC-ARP-6T2-6T2C0C") if the person has a desk. Corresponds to the JSON property location

Returns:

  • (String)


5430
5431
5432
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5430

def location
  @location
end

#managersArray<Google::Apis::CloudsearchV1::PersonCore>

The profile owner's management chain from top to bottom, where managers[0] is the CEO, manager[N-2] is the person's manager's manager and managers[N-1] is the person's direct manager. Note that not all fields of these PersonCores will be set, in particular, relationships will be empty. Corresponds to the JSON property managers



5438
5439
5440
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5438

def managers
  @managers
end

#missionString

Custom mission statement the profile owner has added. Corresponds to the JSON property mission

Returns:

  • (String)


5443
5444
5445
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5443

def mission
  @mission
end

#nameString

Human-readable Unicode display name. Corresponds to the JSON property name

Returns:

  • (String)


5448
5449
5450
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5448

def name
  @name
end

#office_locationString

Office/building identifier within the company. For google.com this is the office code (e.g. "DE-MUC-ARP"). Corresponds to the JSON property officeLocation

Returns:

  • (String)


5454
5455
5456
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5454

def office_location
  @office_location
end

#person_idString

The person's obfuscated Gaia ID. Corresponds to the JSON property personId

Returns:

  • (String)


5459
5460
5461
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5459

def person_id
  @person_id
end

#phone_numbersArray<Google::Apis::CloudsearchV1::EnterpriseTopazFrontendTeamsPersonCorePhoneNumber>

Corresponds to the JSON property phoneNumbers



5464
5465
5466
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5464

def phone_numbers
  @phone_numbers
end

#photo_urlGoogle::Apis::CloudsearchV1::SafeUrlProto

Message containing a string that is safe to use in URL contexts in DOM APIs and HTML documents, where the URL context does not refer to a resource that loads code. Corresponds to the JSON property photoUrl



5471
5472
5473
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5471

def photo_url
  @photo_url
end

#postal_addressString

Postal address of office/building. Corresponds to the JSON property postalAddress

Returns:

  • (String)


5476
5477
5478
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5476

def postal_address
  @postal_address
end

#total_direct_reports_countFixnum

Total count of the profile owner's direct reports. Corresponds to the JSON property totalDirectReportsCount

Returns:

  • (Fixnum)


5481
5482
5483
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5481

def total_direct_reports_count
  @total_direct_reports_count
end

#total_dlr_countFixnum

Total count of the profile owner's dotted-line reports. Corresponds to the JSON property totalDlrCount

Returns:

  • (Fixnum)


5486
5487
5488
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5486

def total_dlr_count
  @total_dlr_count
end

#total_fte_countFixnum

The sum of all profile owner's reports and their own full-time-equivalents in ‰ (e.g. 1800 if one report is working 80% and profile owner 100%). Corresponds to the JSON property totalFteCount

Returns:

  • (Fixnum)


5492
5493
5494
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5492

def total_fte_count
  @total_fte_count
end

#usernameString

External ID of type "login_id" for the profile. For google.com this is the username/LDAP. Corresponds to the JSON property username

Returns:

  • (String)


5498
5499
5500
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5498

def username
  @username
end

#waldo_come_back_timeString

Corresponds to the JSON property waldoComeBackTime

Returns:

  • (String)


5503
5504
5505
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5503

def waldo_come_back_time
  @waldo_come_back_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
5542
5543
5544
5545
5546
5547
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5510

def update!(**args)
  @address_me_as = args[:address_me_as] if args.key?(:address_me_as)
  @admin_to = args[:admin_to] if args.key?(:admin_to)
  @admins = args[:admins] if args.key?(:admins)
  @availability_status = args[:availability_status] if args.key?(:availability_status)
  @birthday = args[:birthday] if args.key?(:birthday)
  @calendar_url = args[:calendar_url] if args.key?(:calendar_url)
  @chat_url = args[:chat_url] if args.key?(:chat_url)
  @cost_center = args[:cost_center] if args.key?(:cost_center)
  @department = args[:department] if args.key?(:department)
  @direct_reports = args[:direct_reports] if args.key?(:direct_reports)
  @dotted_line_managers = args[:dotted_line_managers] if args.key?(:dotted_line_managers)
  @dotted_line_reports = args[:dotted_line_reports] if args.key?(:dotted_line_reports)
  @emails = args[:emails] if args.key?(:emails)
  @employee_id = args[:employee_id] if args.key?(:employee_id)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @fte_permille = args[:fte_permille] if args.key?(:fte_permille)
  @geo_location = args[:geo_location] if args.key?(:geo_location)
  @gmail_url = args[:gmail_url] if args.key?(:gmail_url)
  @job_title = args[:job_title] if args.key?(:job_title)
  @keyword_types = args[:keyword_types] if args.key?(:keyword_types)
  @keywords = args[:keywords] if args.key?(:keywords)
  @links = args[:links] if args.key?(:links)
  @location = args[:location] if args.key?(:location)
  @managers = args[:managers] if args.key?(:managers)
  @mission = args[:mission] if args.key?(:mission)
  @name = args[:name] if args.key?(:name)
  @office_location = args[:office_location] if args.key?(:office_location)
  @person_id = args[:person_id] if args.key?(:person_id)
  @phone_numbers = args[:phone_numbers] if args.key?(:phone_numbers)
  @photo_url = args[:photo_url] if args.key?(:photo_url)
  @postal_address = args[:postal_address] if args.key?(:postal_address)
  @total_direct_reports_count = args[:total_direct_reports_count] if args.key?(:total_direct_reports_count)
  @total_dlr_count = args[:total_dlr_count] if args.key?(:total_dlr_count)
  @total_fte_count = args[:total_fte_count] if args.key?(:total_fte_count)
  @username = args[:username] if args.key?(:username)
  @waldo_come_back_time = args[:waldo_come_back_time] if args.key?(:waldo_come_back_time)
end