Class: Google::Apis::CloudsearchV1::PropertyDefinition
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::PropertyDefinition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
The definition of a property within an object.
Instance Attribute Summary collapse
-
#boolean_property_options ⇒ Google::Apis::CloudsearchV1::BooleanPropertyOptions
The options for boolean properties.
-
#date_property_options ⇒ Google::Apis::CloudsearchV1::DatePropertyOptions
The options for date properties.
-
#display_options ⇒ Google::Apis::CloudsearchV1::PropertyDisplayOptions
The display options for a property.
-
#double_property_options ⇒ Google::Apis::CloudsearchV1::DoublePropertyOptions
The options for double properties.
-
#enum_property_options ⇒ Google::Apis::CloudsearchV1::EnumPropertyOptions
The options for enum properties, which allow you to define a restricted set of strings to match user queries, set rankings for those string values, and define an operator name to be paired with those strings so that users can narrow results to only items with a specific value.
-
#html_property_options ⇒ Google::Apis::CloudsearchV1::HtmlPropertyOptions
The options for html properties.
-
#integer_property_options ⇒ Google::Apis::CloudsearchV1::IntegerPropertyOptions
The options for integer properties.
-
#is_facetable ⇒ Boolean
(also: #is_facetable?)
Indicates that the property can be used for generating facets.
-
#is_repeatable ⇒ Boolean
(also: #is_repeatable?)
Indicates that multiple values are allowed for the property.
-
#is_returnable ⇒ Boolean
(also: #is_returnable?)
Indicates that the property identifies data that should be returned in search results via the Query API.
-
#is_sortable ⇒ Boolean
(also: #is_sortable?)
Indicates that the property can be used for sorting.
-
#is_suggestable ⇒ Boolean
(also: #is_suggestable?)
Indicates that the property can be used for generating query suggestions.
-
#is_wildcard_searchable ⇒ Boolean
(also: #is_wildcard_searchable?)
Indicates that users can perform wildcard search for this property.
-
#name ⇒ String
The name of the property.
-
#object_property_options ⇒ Google::Apis::CloudsearchV1::ObjectPropertyOptions
The options for object properties.
-
#text_property_options ⇒ Google::Apis::CloudsearchV1::TextPropertyOptions
The options for text properties.
-
#timestamp_property_options ⇒ Google::Apis::CloudsearchV1::TimestampPropertyOptions
The options for timestamp properties.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PropertyDefinition
constructor
A new instance of PropertyDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PropertyDefinition
Returns a new instance of PropertyDefinition.
5857 5858 5859 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_property_options ⇒ Google::Apis::CloudsearchV1::BooleanPropertyOptions
The options for boolean properties.
Corresponds to the JSON property booleanPropertyOptions
5735 5736 5737 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5735 def @boolean_property_options end |
#date_property_options ⇒ Google::Apis::CloudsearchV1::DatePropertyOptions
The options for date properties.
Corresponds to the JSON property datePropertyOptions
5740 5741 5742 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5740 def @date_property_options end |
#display_options ⇒ Google::Apis::CloudsearchV1::PropertyDisplayOptions
The display options for a property.
Corresponds to the JSON property displayOptions
5745 5746 5747 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5745 def @display_options end |
#double_property_options ⇒ Google::Apis::CloudsearchV1::DoublePropertyOptions
The options for double properties.
Corresponds to the JSON property doublePropertyOptions
5750 5751 5752 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5750 def @double_property_options end |
#enum_property_options ⇒ Google::Apis::CloudsearchV1::EnumPropertyOptions
The options for enum properties, which allow you to define a restricted set of
strings to match user queries, set rankings for those string values, and
define an operator name to be paired with those strings so that users can
narrow results to only items with a specific value. For example, for items in
a request tracking system with priority information, you could define p0 as
an allowable enum value and tie this enum to the operator name priority so
that search users could add priority:p0 to their query to restrict the set
of results to only those items indexed with the value p0.
Corresponds to the JSON property enumPropertyOptions
5762 5763 5764 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5762 def @enum_property_options end |
#html_property_options ⇒ Google::Apis::CloudsearchV1::HtmlPropertyOptions
The options for html properties.
Corresponds to the JSON property htmlPropertyOptions
5767 5768 5769 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5767 def @html_property_options end |
#integer_property_options ⇒ Google::Apis::CloudsearchV1::IntegerPropertyOptions
The options for integer properties.
Corresponds to the JSON property integerPropertyOptions
5772 5773 5774 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5772 def @integer_property_options end |
#is_facetable ⇒ Boolean Also known as: is_facetable?
Indicates that the property can be used for generating facets. Cannot be true
for properties whose type is object. IsReturnable must be true to set this
option. Only supported for boolean, enum, integer, and text properties.
Corresponds to the JSON property isFacetable
5779 5780 5781 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5779 def is_facetable @is_facetable end |
#is_repeatable ⇒ Boolean Also known as: is_repeatable?
Indicates that multiple values are allowed for the property. For example, a
document only has one description but can have multiple comments. Cannot be
true for properties whose type is a boolean. If set to false, properties that
contain more than one value cause the indexing request for that item to be
rejected.
Corresponds to the JSON property isRepeatable
5789 5790 5791 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5789 def is_repeatable @is_repeatable end |
#is_returnable ⇒ Boolean Also known as: is_returnable?
Indicates that the property identifies data that should be returned in search
results via the Query API. If set to true, indicates that Query API users
can use matching property fields in results. However, storing fields requires
more space allocation and uses more bandwidth for search queries, which
impacts performance over large datasets. Set to true here only if the field
is needed for search results. Cannot be true for properties whose type is an
object.
Corresponds to the JSON property isReturnable
5801 5802 5803 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5801 def is_returnable @is_returnable end |
#is_sortable ⇒ Boolean Also known as: is_sortable?
Indicates that the property can be used for sorting. Cannot be true for
properties that are repeatable. Cannot be true for properties whose type is
object. IsReturnable must be true to set this option. Only supported for
boolean, date, double, integer, and timestamp properties.
Corresponds to the JSON property isSortable
5810 5811 5812 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5810 def is_sortable @is_sortable end |
#is_suggestable ⇒ Boolean Also known as: is_suggestable?
Indicates that the property can be used for generating query suggestions.
Corresponds to the JSON property isSuggestable
5816 5817 5818 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5816 def is_suggestable @is_suggestable end |
#is_wildcard_searchable ⇒ Boolean Also known as: is_wildcard_searchable?
Indicates that users can perform wildcard search for this property. Only
supported for Text properties. IsReturnable must be true to set this option.
In a given datasource maximum of 5 properties can be marked as
is_wildcard_searchable. For more details, see Define object properties
Corresponds to the JSON property isWildcardSearchable
5827 5828 5829 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5827 def is_wildcard_searchable @is_wildcard_searchable end |
#name ⇒ String
The name of the property. Item indexing requests sent to the Indexing API
should set the property name equal to this value. For example, if name is *
subject_line*, then indexing requests for document items with subject fields
should set the name for that field equal to subject_line. Use the name as
the identifier for the object property. Once registered as a property for an
object, you cannot re-use this name for another property within that object.
The name must start with a letter and can only contain letters (A-Z, a-z) or
numbers (0-9). The maximum length is 256 characters.
Corresponds to the JSON property name
5840 5841 5842 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5840 def name @name end |
#object_property_options ⇒ Google::Apis::CloudsearchV1::ObjectPropertyOptions
The options for object properties.
Corresponds to the JSON property objectPropertyOptions
5845 5846 5847 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5845 def @object_property_options end |
#text_property_options ⇒ Google::Apis::CloudsearchV1::TextPropertyOptions
The options for text properties.
Corresponds to the JSON property textPropertyOptions
5850 5851 5852 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5850 def @text_property_options end |
#timestamp_property_options ⇒ Google::Apis::CloudsearchV1::TimestampPropertyOptions
The options for timestamp properties.
Corresponds to the JSON property timestampPropertyOptions
5855 5856 5857 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5855 def @timestamp_property_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5862 def update!(**args) @boolean_property_options = args[:boolean_property_options] if args.key?(:boolean_property_options) @date_property_options = args[:date_property_options] if args.key?(:date_property_options) @display_options = args[:display_options] if args.key?(:display_options) @double_property_options = args[:double_property_options] if args.key?(:double_property_options) @enum_property_options = args[:enum_property_options] if args.key?(:enum_property_options) @html_property_options = args[:html_property_options] if args.key?(:html_property_options) @integer_property_options = args[:integer_property_options] if args.key?(:integer_property_options) @is_facetable = args[:is_facetable] if args.key?(:is_facetable) @is_repeatable = args[:is_repeatable] if args.key?(:is_repeatable) @is_returnable = args[:is_returnable] if args.key?(:is_returnable) @is_sortable = args[:is_sortable] if args.key?(:is_sortable) @is_suggestable = args[:is_suggestable] if args.key?(:is_suggestable) @is_wildcard_searchable = args[:is_wildcard_searchable] if args.key?(:is_wildcard_searchable) @name = args[:name] if args.key?(:name) @object_property_options = args[:object_property_options] if args.key?(:object_property_options) @text_property_options = args[:text_property_options] if args.key?(:text_property_options) @timestamp_property_options = args[:timestamp_property_options] if args.key?(:timestamp_property_options) end |