Class: Google::Apis::CloudsearchV1::PushItem

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Represents an item to be pushed to the indexing queue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PushItem

Returns a new instance of PushItem.



5959
5960
5961
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_hashString

Content hash of the item according to the repository. If specified, this is used to determine how to modify this item's status. Setting this field and the type field results in argument error. The maximum length is 2048 characters. Corresponds to the JSON property contentHash

Returns:

  • (String)


5918
5919
5920
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5918

def content_hash
  @content_hash
end

#metadata_hashString

The metadata hash of the item according to the repository. If specified, this is used to determine how to modify this item's status. Setting this field and the type field results in argument error. The maximum length is 2048 characters. Corresponds to the JSON property metadataHash

Returns:

  • (String)


5926
5927
5928
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5926

def 
  @metadata_hash
end

#payloadString

Provides additional document state information for the connector, such as an alternate repository ID and other metadata. The maximum length is 8192 bytes. Corresponds to the JSON property payload NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5933
5934
5935
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5933

def payload
  @payload
end

#queueString

Queue to which this item belongs. The default queue is chosen if this field is not specified. The maximum length is 512 characters. Corresponds to the JSON property queue

Returns:

  • (String)


5939
5940
5941
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5939

def queue
  @queue
end

#repository_errorGoogle::Apis::CloudsearchV1::RepositoryError

Errors when the connector is communicating to the source repository. Corresponds to the JSON property repositoryError



5944
5945
5946
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5944

def repository_error
  @repository_error
end

#structured_data_hashString

Structured data hash of the item according to the repository. If specified, this is used to determine how to modify this item's status. Setting this field and the type field results in argument error. The maximum length is 2048 characters. Corresponds to the JSON property structuredDataHash

Returns:

  • (String)


5952
5953
5954
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5952

def structured_data_hash
  @structured_data_hash
end

#typeString

The type of the push operation that defines the push behavior. Corresponds to the JSON property type

Returns:

  • (String)


5957
5958
5959
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5957

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5964
5965
5966
5967
5968
5969
5970
5971
5972
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 5964

def update!(**args)
  @content_hash = args[:content_hash] if args.key?(:content_hash)
  @metadata_hash = args[:metadata_hash] if args.key?(:metadata_hash)
  @payload = args[:payload] if args.key?(:payload)
  @queue = args[:queue] if args.key?(:queue)
  @repository_error = args[:repository_error] if args.key?(:repository_error)
  @structured_data_hash = args[:structured_data_hash] if args.key?(:structured_data_hash)
  @type = args[:type] if args.key?(:type)
end