Class: Google::Apis::CloudsearchV1::QueryInterpretationOptions
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::QueryInterpretationOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
Options to interpret user query.
Instance Attribute Summary collapse
-
#disable_nl_interpretation ⇒ Boolean
(also: #disable_nl_interpretation?)
Flag to disable natural language (NL) interpretation of queries.
-
#disable_supplemental_results ⇒ Boolean
(also: #disable_supplemental_results?)
Use this flag to disable supplemental results for a query.
-
#enable_verbatim_mode ⇒ Boolean
(also: #enable_verbatim_mode?)
Enable this flag to turn off all internal optimizations like natural language ( NL) interpretation of queries, supplemental result retrieval, and usage of synonyms including custom ones.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryInterpretationOptions
constructor
A new instance of QueryInterpretationOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryInterpretationOptions
Returns a new instance of QueryInterpretationOptions.
6162 6163 6164 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_nl_interpretation ⇒ Boolean Also known as: disable_nl_interpretation?
Flag to disable natural language (NL) interpretation of queries. Default is
false, Set to true to disable natural language interpretation. NL
interpretation only applies to predefined datasources.
Corresponds to the JSON property disableNlInterpretation
6142 6143 6144 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6142 def disable_nl_interpretation @disable_nl_interpretation end |
#disable_supplemental_results ⇒ Boolean Also known as: disable_supplemental_results?
Use this flag to disable supplemental results for a query. Supplemental
results setting chosen at SearchApplication level will take precedence if set
to True.
Corresponds to the JSON property disableSupplementalResults
6150 6151 6152 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6150 def disable_supplemental_results @disable_supplemental_results end |
#enable_verbatim_mode ⇒ Boolean Also known as: enable_verbatim_mode?
Enable this flag to turn off all internal optimizations like natural language (
NL) interpretation of queries, supplemental result retrieval, and usage of
synonyms including custom ones. Nl interpretation will be disabled if either
one of the two flags is true.
Corresponds to the JSON property enableVerbatimMode
6159 6160 6161 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6159 def enable_verbatim_mode @enable_verbatim_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6167 6168 6169 6170 6171 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6167 def update!(**args) @disable_nl_interpretation = args[:disable_nl_interpretation] if args.key?(:disable_nl_interpretation) @disable_supplemental_results = args[:disable_supplemental_results] if args.key?(:disable_supplemental_results) @enable_verbatim_mode = args[:enable_verbatim_mode] if args.key?(:enable_verbatim_mode) end |