Class: Google::Apis::CloudsearchV1::QueryOperator

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

The definition of a operator that can be used in a Search/Suggest request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryOperator

Returns a new instance of QueryOperator.



6268
6269
6270
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Display name of the operator Corresponds to the JSON property displayName

Returns:

  • (String)


6201
6202
6203
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6201

def display_name
  @display_name
end

#enum_valuesArray<String>

Potential list of values for the opeatror field. This field is only filled when we can safely enumerate all the possible values of this operator. Corresponds to the JSON property enumValues

Returns:

  • (Array<String>)


6207
6208
6209
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6207

def enum_values
  @enum_values
end

#greater_than_operator_nameString

Indicates the operator name that can be used to isolate the property using the greater-than operator. Corresponds to the JSON property greaterThanOperatorName

Returns:

  • (String)


6213
6214
6215
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6213

def greater_than_operator_name
  @greater_than_operator_name
end

#is_facetableBoolean Also known as: is_facetable?

Can this operator be used to get facets. Corresponds to the JSON property isFacetable

Returns:

  • (Boolean)


6218
6219
6220
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6218

def is_facetable
  @is_facetable
end

#is_repeatableBoolean Also known as: is_repeatable?

Indicates if multiple values can be set for this property. Corresponds to the JSON property isRepeatable

Returns:

  • (Boolean)


6224
6225
6226
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6224

def is_repeatable
  @is_repeatable
end

#is_returnableBoolean Also known as: is_returnable?

Will the property associated with this facet be returned as part of search results. Corresponds to the JSON property isReturnable

Returns:

  • (Boolean)


6231
6232
6233
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6231

def is_returnable
  @is_returnable
end

#is_sortableBoolean Also known as: is_sortable?

Can this operator be used to sort results. Corresponds to the JSON property isSortable

Returns:

  • (Boolean)


6237
6238
6239
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6237

def is_sortable
  @is_sortable
end

#is_suggestableBoolean Also known as: is_suggestable?

Can get suggestions for this field. Corresponds to the JSON property isSuggestable

Returns:

  • (Boolean)


6243
6244
6245
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6243

def is_suggestable
  @is_suggestable
end

#less_than_operator_nameString

Indicates the operator name that can be used to isolate the property using the less-than operator. Corresponds to the JSON property lessThanOperatorName

Returns:

  • (String)


6250
6251
6252
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6250

def less_than_operator_name
  @less_than_operator_name
end

#object_typeString

The name of the object corresponding to the operator. This field is only filled for schema-specific operators, and is unset for common operators. Corresponds to the JSON property objectType

Returns:

  • (String)


6256
6257
6258
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6256

def object_type
  @object_type
end

#operator_nameString

The name of the operator. Corresponds to the JSON property operatorName

Returns:

  • (String)


6261
6262
6263
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6261

def operator_name
  @operator_name
end

#typeString

The type of the operator. Corresponds to the JSON property type

Returns:

  • (String)


6266
6267
6268
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6266

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6273

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enum_values = args[:enum_values] if args.key?(:enum_values)
  @greater_than_operator_name = args[:greater_than_operator_name] if args.key?(:greater_than_operator_name)
  @is_facetable = args[:is_facetable] if args.key?(:is_facetable)
  @is_repeatable = args[:is_repeatable] if args.key?(:is_repeatable)
  @is_returnable = args[:is_returnable] if args.key?(:is_returnable)
  @is_sortable = args[:is_sortable] if args.key?(:is_sortable)
  @is_suggestable = args[:is_suggestable] if args.key?(:is_suggestable)
  @less_than_operator_name = args[:less_than_operator_name] if args.key?(:less_than_operator_name)
  @object_type = args[:object_type] if args.key?(:object_type)
  @operator_name = args[:operator_name] if args.key?(:operator_name)
  @type = args[:type] if args.key?(:type)
end