Class: Google::Apis::CloudsearchV1::QuerySuggestion
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::QuerySuggestion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Instance Attribute Summary collapse
-
#last_query_time ⇒ String
Last query time of the suggestion for query history suggestions.
-
#source_corpus ⇒ String
Source corpus of the suggestion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuerySuggestion
constructor
A new instance of QuerySuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuerySuggestion
Returns a new instance of QuerySuggestion.
6341 6342 6343 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_query_time ⇒ String
Last query time of the suggestion for query history suggestions.
Corresponds to the JSON property lastQueryTime
6334 6335 6336 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6334 def last_query_time @last_query_time end |
#source_corpus ⇒ String
Source corpus of the suggestion.
Corresponds to the JSON property sourceCorpus
6339 6340 6341 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6339 def source_corpus @source_corpus end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6346 6347 6348 6349 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6346 def update!(**args) @last_query_time = args[:last_query_time] if args.key?(:last_query_time) @source_corpus = args[:source_corpus] if args.key?(:source_corpus) end |