Class: Google::Apis::CloudsearchV1::ResultDisplayField

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Display Fields for Search Results

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResultDisplayField

Returns a new instance of ResultDisplayField.



6628
6629
6630
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelString

The display label for the property. Corresponds to the JSON property label

Returns:

  • (String)


6614
6615
6616
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6614

def label
  @label
end

#operator_nameString

The operator name of the property. Corresponds to the JSON property operatorName

Returns:

  • (String)


6619
6620
6621
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6619

def operator_name
  @operator_name
end

#propertyGoogle::Apis::CloudsearchV1::NamedProperty

A typed name-value pair for structured data. The type of the value should be the same as the registered type for the name property in the object definition of objectType. Corresponds to the JSON property property



6626
6627
6628
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6626

def property
  @property
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6633
6634
6635
6636
6637
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6633

def update!(**args)
  @label = args[:label] if args.key?(:label)
  @operator_name = args[:operator_name] if args.key?(:operator_name)
  @property = args[:property] if args.key?(:property)
end