Class: Google::Apis::CloudsearchV1::SafeHtmlProto
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::SafeHtmlProto
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
IMPORTANT: It is unsafe to accept this message from an untrusted source, since it's trivial for an attacker to forge serialized messages that don't fulfill the type's safety contract -- for example, it could contain attacker controlled script. A system which receives a SafeHtmlProto implicitly trusts the producer of the SafeHtmlProto. So, it's generally safe to return this message in RPC responses, but generally unsafe to accept it in RPC requests.
Instance Attribute Summary collapse
-
#private_do_not_access_or_else_safe_html_wrapped_value ⇒ String
IMPORTANT: Never set or read this field, even from tests, it is private.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SafeHtmlProto
constructor
A new instance of SafeHtmlProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SafeHtmlProto
Returns a new instance of SafeHtmlProto.
6720 6721 6722 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6720 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_do_not_access_or_else_safe_html_wrapped_value ⇒ String
IMPORTANT: Never set or read this field, even from tests, it is private. See
documentation at the top of .proto file for programming language packages with
which to create or read this message.
Corresponds to the JSON property privateDoNotAccessOrElseSafeHtmlWrappedValue
6718 6719 6720 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6718 def private_do_not_access_or_else_safe_html_wrapped_value @private_do_not_access_or_else_safe_html_wrapped_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6725 6726 6727 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6725 def update!(**args) @private_do_not_access_or_else_safe_html_wrapped_value = args[:private_do_not_access_or_else_safe_html_wrapped_value] if args.key?(:private_do_not_access_or_else_safe_html_wrapped_value) end |