Class: Google::Apis::CloudsearchV1::SafeUrlProto

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Message containing a string that is safe to use in URL contexts in DOM APIs and HTML documents, where the URL context does not refer to a resource that loads code.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SafeUrlProto

Returns a new instance of SafeUrlProto.



6735
6736
6737
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_do_not_access_or_else_safe_url_wrapped_valueString

IMPORTANT: Never set or read this field, even from tests, it is private. See documentation at the top of .proto file for programming language packages with which to create or read this message. Corresponds to the JSON property privateDoNotAccessOrElseSafeUrlWrappedValue

Returns:

  • (String)


6733
6734
6735
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6733

def private_do_not_access_or_else_safe_url_wrapped_value
  @private_do_not_access_or_else_safe_url_wrapped_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6740
6741
6742
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6740

def update!(**args)
  @private_do_not_access_or_else_safe_url_wrapped_value = args[:private_do_not_access_or_else_safe_url_wrapped_value] if args.key?(:private_do_not_access_or_else_safe_url_wrapped_value)
end