Class: Google::Apis::CloudsearchV1::SearchApplicationQueryStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Search application level query stats per date

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchApplicationQueryStats

Returns a new instance of SearchApplicationQueryStats.



6916
6917
6918
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dateGoogle::Apis::CloudsearchV1::Date

Represents a whole calendar date, for example a date of birth. The time of day and time zone are either specified elsewhere or are not significant. The date is relative to the Proleptic Gregorian Calendar. The date must be a valid calendar date between the year 1 and 9999. Corresponds to the JSON property date



6909
6910
6911
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6909

def date
  @date
end

#query_count_by_statusArray<Google::Apis::CloudsearchV1::QueryCountByStatus>

Corresponds to the JSON property queryCountByStatus



6914
6915
6916
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6914

def query_count_by_status
  @query_count_by_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6921
6922
6923
6924
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6921

def update!(**args)
  @date = args[:date] if args.key?(:date)
  @query_count_by_status = args[:query_count_by_status] if args.key?(:query_count_by_status)
end