Class: Google::Apis::CloudsearchV1::SearchApplicationSessionStats
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::SearchApplicationSessionStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Instance Attribute Summary collapse
-
#date ⇒ Google::Apis::CloudsearchV1::Date
Represents a whole calendar date, for example a date of birth.
-
#search_sessions_count ⇒ Fixnum
The count of search sessions on the day Corresponds to the JSON property
searchSessionsCount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchApplicationSessionStats
constructor
A new instance of SearchApplicationSessionStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchApplicationSessionStats
Returns a new instance of SearchApplicationSessionStats.
6945 6946 6947 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6945 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date ⇒ Google::Apis::CloudsearchV1::Date
Represents a whole calendar date, for example a date of birth. The time of day
and time zone are either specified elsewhere or are not significant. The date
is relative to the Proleptic Gregorian Calendar. The date must be a valid calendar date
between the year 1 and 9999.
Corresponds to the JSON property date
6938 6939 6940 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6938 def date @date end |
#search_sessions_count ⇒ Fixnum
The count of search sessions on the day
Corresponds to the JSON property searchSessionsCount
6943 6944 6945 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6943 def search_sessions_count @search_sessions_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6950 6951 6952 6953 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6950 def update!(**args) @date = args[:date] if args.key?(:date) @search_sessions_count = args[:search_sessions_count] if args.key?(:search_sessions_count) end |