Class: Google::Apis::CloudsearchV1::SearchQualityMetadata
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::SearchQualityMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
Additional search quality metadata of the item.
Instance Attribute Summary collapse
-
#quality ⇒ Float
An indication of the quality of the item, used to influence search quality.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchQualityMetadata
constructor
A new instance of SearchQualityMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchQualityMetadata
Returns a new instance of SearchQualityMetadata.
7058 7059 7060 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7058 def initialize(**args) update!(**args) end |
Instance Attribute Details
#quality ⇒ Float
An indication of the quality of the item, used to influence search quality.
Value should be between 0.0 (lowest quality) and 1.0 (highest quality). The
default value is 0.0.
Corresponds to the JSON property quality
7056 7057 7058 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7056 def quality @quality end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7063 7064 7065 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7063 def update!(**args) @quality = args[:quality] if args.key?(:quality) end |