Class: Google::Apis::CloudsearchV1::SearchResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Results containing indexed information for a document. Next ID: 17

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchResult

Returns a new instance of SearchResult.



7268
7269
7270
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clustered_resultsArray<Google::Apis::CloudsearchV1::SearchResult>

If source is clustered, provide list of clustered results. There will only be one level of clustered results. If current source is not enabled for clustering, this field will be empty. Corresponds to the JSON property clusteredResults



7239
7240
7241
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7239

def clustered_results
  @clustered_results
end

#debug_infoGoogle::Apis::CloudsearchV1::ResultDebugInfo

Debugging information about the result. Corresponds to the JSON property debugInfo



7244
7245
7246
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7244

def debug_info
  @debug_info
end

#metadataGoogle::Apis::CloudsearchV1::Metadata

Metadata of a matched search result. Corresponds to the JSON property metadata



7249
7250
7251
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7249

def 
  @metadata
end

#snippetGoogle::Apis::CloudsearchV1::Snippet

Snippet of the search result, which summarizes the content of the resulting page. Corresponds to the JSON property snippet



7255
7256
7257
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7255

def snippet
  @snippet
end

#titleString

Title of the search result. Corresponds to the JSON property title

Returns:

  • (String)


7260
7261
7262
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7260

def title
  @title
end

#urlString

The URL of the search result. The URL contains a Google redirect to the actual item. This URL is signed and shouldn't be changed. Corresponds to the JSON property url

Returns:

  • (String)


7266
7267
7268
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7266

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7273
7274
7275
7276
7277
7278
7279
7280
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7273

def update!(**args)
  @clustered_results = args[:clustered_results] if args.key?(:clustered_results)
  @debug_info = args[:debug_info] if args.key?(:debug_info)
  @metadata = args[:metadata] if args.key?(:metadata)
  @snippet = args[:snippet] if args.key?(:snippet)
  @title = args[:title] if args.key?(:title)
  @url = args[:url] if args.key?(:url)
end