Class: Google::Apis::CloudsearchV1::SpellResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpellResult

Returns a new instance of SpellResult.



7512
7513
7514
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#suggested_queryString

The suggested spelling of the query. Corresponds to the JSON property suggestedQuery

Returns:

  • (String)


7495
7496
7497
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7495

def suggested_query
  @suggested_query
end

#suggested_query_htmlGoogle::Apis::CloudsearchV1::SafeHtmlProto

IMPORTANT: It is unsafe to accept this message from an untrusted source, since it's trivial for an attacker to forge serialized messages that don't fulfill the type's safety contract -- for example, it could contain attacker controlled script. A system which receives a SafeHtmlProto implicitly trusts the producer of the SafeHtmlProto. So, it's generally safe to return this message in RPC responses, but generally unsafe to accept it in RPC requests. Corresponds to the JSON property suggestedQueryHtml



7505
7506
7507
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7505

def suggested_query_html
  @suggested_query_html
end

#suggestion_typeString

Suggestion triggered for the current query. Corresponds to the JSON property suggestionType

Returns:

  • (String)


7510
7511
7512
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7510

def suggestion_type
  @suggestion_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7517
7518
7519
7520
7521
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7517

def update!(**args)
  @suggested_query = args[:suggested_query] if args.key?(:suggested_query)
  @suggested_query_html = args[:suggested_query_html] if args.key?(:suggested_query_html)
  @suggestion_type = args[:suggestion_type] if args.key?(:suggestion_type)
end