Class: Google::Apis::CloudsearchV1::TextPropertyOptions
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::TextPropertyOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
The options for text properties.
Instance Attribute Summary collapse
-
#operator_options ⇒ Google::Apis::CloudsearchV1::TextOperatorOptions
Used to provide a search operator for text properties.
-
#retrieval_importance ⇒ Google::Apis::CloudsearchV1::RetrievalImportance
Indicates the search quality importance of the tokens within the field when used for retrieval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TextPropertyOptions
constructor
A new instance of TextPropertyOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TextPropertyOptions
Returns a new instance of TextPropertyOptions.
7778 7779 7780 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operator_options ⇒ Google::Apis::CloudsearchV1::TextOperatorOptions
Used to provide a search operator for text properties. This is optional.
Search operators let users restrict the query to specific fields relevant to
the type of item being searched.
Corresponds to the JSON property operatorOptions
7770 7771 7772 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7770 def @operator_options end |
#retrieval_importance ⇒ Google::Apis::CloudsearchV1::RetrievalImportance
Indicates the search quality importance of the tokens within the field when
used for retrieval.
Corresponds to the JSON property retrievalImportance
7776 7777 7778 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7776 def retrieval_importance @retrieval_importance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7783 7784 7785 7786 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7783 def update!(**args) @operator_options = args[:operator_options] if args.key?(:operator_options) @retrieval_importance = args[:retrieval_importance] if args.key?(:retrieval_importance) end |