Class: Google::Apis::CloudsearchV1::TimestampOperatorOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Used to provide a search operator for timestamp properties. This is optional. Search operators let users restrict the query to specific fields relevant to the type of item being searched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimestampOperatorOptions

Returns a new instance of TimestampOperatorOptions.



7896
7897
7898
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#greater_than_operator_nameString

Indicates the operator name required in the query in order to isolate the timestamp property using the greater-than operator. For example, if greaterThanOperatorName is closedafter and the property's name is closeDate , then queries like closedafter: show results only where the value of the property named closeDate is later than . The operator name can only contain lowercase letters (a-z). The maximum length is 32 characters. Corresponds to the JSON property greaterThanOperatorName

Returns:

  • (String)


7872
7873
7874
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7872

def greater_than_operator_name
  @greater_than_operator_name
end

#less_than_operator_nameString

Indicates the operator name required in the query in order to isolate the timestamp property using the less-than operator. For example, if lessThanOperatorName is closedbefore and the property's name is closeDate, then queries like closedbefore: show results only where the value of the property named closeDate is earlier than . The operator name can only contain lowercase letters (a-z). The maximum length is 32 characters. Corresponds to the JSON property lessThanOperatorName

Returns:

  • (String)


7882
7883
7884
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7882

def less_than_operator_name
  @less_than_operator_name
end

#operator_nameString

Indicates the operator name required in the query in order to isolate the timestamp property. For example, if operatorName is closedon and the property's name is closeDate, then queries like closedon: show results only where the value of the property named closeDate matches *. By contrast, a search that uses the same * without an operator returns all items where matches the value of any String properties or text within the content field for the item. The operator name can only contain lowercase letters (a-z). The maximum length is 32 characters. Corresponds to the JSON property operatorName

Returns:

  • (String)


7894
7895
7896
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7894

def operator_name
  @operator_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7901
7902
7903
7904
7905
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7901

def update!(**args)
  @greater_than_operator_name = args[:greater_than_operator_name] if args.key?(:greater_than_operator_name)
  @less_than_operator_name = args[:less_than_operator_name] if args.key?(:less_than_operator_name)
  @operator_name = args[:operator_name] if args.key?(:operator_name)
end