Class: Google::Apis::CloudsearchV1::UpdateDataSourceRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::UpdateDataSourceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Instance Attribute Summary collapse
-
#debug_options ⇒ Google::Apis::CloudsearchV1::DebugOptions
Shared request debug options for all cloudsearch RPC methods.
-
#source ⇒ Google::Apis::CloudsearchV1::DataSource
Datasource is a logical namespace for items to be indexed.
-
#update_mask ⇒ String
Only applies to
settings.datasources.patch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateDataSourceRequest
constructor
A new instance of UpdateDataSourceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateDataSourceRequest
Returns a new instance of UpdateDataSourceRequest.
8025 8026 8027 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#debug_options ⇒ Google::Apis::CloudsearchV1::DebugOptions
Shared request debug options for all cloudsearch RPC methods.
Corresponds to the JSON property debugOptions
8004 8005 8006 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8004 def @debug_options end |
#source ⇒ Google::Apis::CloudsearchV1::DataSource
Datasource is a logical namespace for items to be indexed. All items must
belong to a datasource. This is the prerequisite before items can be indexed
into Cloud Search.
Corresponds to the JSON property source
8011 8012 8013 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8011 def source @source end |
#update_mask ⇒ String
Only applies to settings.datasources.patch.
Update mask to control which fields to update. Example field paths: name,
displayName. * If update_mask is non-empty, then only the fields specified
in the update_mask are updated. * If you specify a field in the update_mask
, but don't specify its value in the source, that field is cleared. * If the
update_mask is not present or empty or has the value *, then all fields are
updated.
Corresponds to the JSON property updateMask
8023 8024 8025 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8023 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8030 8031 8032 8033 8034 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8030 def update!(**args) @debug_options = args[:debug_options] if args.key?(:debug_options) @source = args[:source] if args.key?(:source) @update_mask = args[:update_mask] if args.key?(:update_mask) end |