Class: Google::Apis::CloudsearchV1::ValueFilter

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValueFilter

Returns a new instance of ValueFilter.



8215
8216
8217
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operator_nameString

The operator_name applied to the query, such as price_greater_than. The filter can work against both types of filters defined in the schema for your data source: 1. operator_name, where the query filters results by the property that matches the value. 2. greater_than_operator_name or less_than_operator_name in your schema. The query filters the results for the property values that are greater than or less than the supplied value in the query. Corresponds to the JSON property operatorName

Returns:

  • (String)


8208
8209
8210
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8208

def operator_name
  @operator_name
end

#valueGoogle::Apis::CloudsearchV1::Value

Definition of a single value with generic type. Corresponds to the JSON property value



8213
8214
8215
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8213

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8220
8221
8222
8223
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8220

def update!(**args)
  @operator_name = args[:operator_name] if args.key?(:operator_name)
  @value = args[:value] if args.key?(:value)
end