Class: Google::Apis::CloudsearchV1::Metadata
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::Metadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
Metadata of a matched search result.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The creation time for this document or object in the search result.
-
#display_options ⇒ Google::Apis::CloudsearchV1::ResultDisplayMetadata
Options that specify how to display a structured data search result.
-
#fields ⇒ Array<Google::Apis::CloudsearchV1::NamedProperty>
Indexed fields in structured data, returned as a generic named property.
-
#mime_type ⇒ String
Mime type of the search result.
-
#object_type ⇒ String
Object type of the search result.
-
#owner ⇒ Google::Apis::CloudsearchV1::Person
Object to represent a person.
-
#source ⇒ Google::Apis::CloudsearchV1::Source
Defines sources for the suggest/search APIs.
-
#thumbnail_url ⇒ String
The thumbnail URL of the result.
-
#update_time ⇒ String
The last modified date for the object in the search result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Metadata
constructor
A new instance of Metadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Metadata
Returns a new instance of Metadata.
4844 4845 4846 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The creation time for this document or object in the search result.
Corresponds to the JSON property createTime
4799 4800 4801 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4799 def create_time @create_time end |
#display_options ⇒ Google::Apis::CloudsearchV1::ResultDisplayMetadata
Options that specify how to display a structured data search result.
Corresponds to the JSON property displayOptions
4804 4805 4806 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4804 def @display_options end |
#fields ⇒ Array<Google::Apis::CloudsearchV1::NamedProperty>
Indexed fields in structured data, returned as a generic named property.
Corresponds to the JSON property fields
4809 4810 4811 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4809 def fields @fields end |
#mime_type ⇒ String
Mime type of the search result.
Corresponds to the JSON property mimeType
4814 4815 4816 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4814 def mime_type @mime_type end |
#object_type ⇒ String
Object type of the search result.
Corresponds to the JSON property objectType
4819 4820 4821 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4819 def object_type @object_type end |
#owner ⇒ Google::Apis::CloudsearchV1::Person
Object to represent a person.
Corresponds to the JSON property owner
4824 4825 4826 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4824 def owner @owner end |
#source ⇒ Google::Apis::CloudsearchV1::Source
Defines sources for the suggest/search APIs.
Corresponds to the JSON property source
4829 4830 4831 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4829 def source @source end |
#thumbnail_url ⇒ String
The thumbnail URL of the result.
Corresponds to the JSON property thumbnailUrl
4834 4835 4836 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4834 def thumbnail_url @thumbnail_url end |
#update_time ⇒ String
The last modified date for the object in the search result. If not set in the
item, the value returned here is empty. When updateTime is used for
calculating freshness and is not set, this value defaults to 2 years from the
current time.
Corresponds to the JSON property updateTime
4842 4843 4844 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4842 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 4849 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_options = args[:display_options] if args.key?(:display_options) @fields = args[:fields] if args.key?(:fields) @mime_type = args[:mime_type] if args.key?(:mime_type) @object_type = args[:object_type] if args.key?(:object_type) @owner = args[:owner] if args.key?(:owner) @source = args[:source] if args.key?(:source) @thumbnail_url = args[:thumbnail_url] if args.key?(:thumbnail_url) @update_time = args[:update_time] if args.key?(:update_time) end |