Class: Google::Apis::CloudsearchV1::QueryOperator
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::QueryOperator
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
The definition of a operator that can be used in a Search/Suggest request.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Display name of the operator Corresponds to the JSON property
displayName. -
#enum_values ⇒ Array<String>
Potential list of values for the opeatror field.
-
#greater_than_operator_name ⇒ String
Indicates the operator name that can be used to isolate the property using the greater-than operator.
-
#is_facetable ⇒ Boolean
(also: #is_facetable?)
Can this operator be used to get facets.
-
#is_repeatable ⇒ Boolean
(also: #is_repeatable?)
Indicates if multiple values can be set for this property.
-
#is_returnable ⇒ Boolean
(also: #is_returnable?)
Will the property associated with this facet be returned as part of search results.
-
#is_sortable ⇒ Boolean
(also: #is_sortable?)
Can this operator be used to sort results.
-
#is_suggestable ⇒ Boolean
(also: #is_suggestable?)
Can get suggestions for this field.
-
#less_than_operator_name ⇒ String
Indicates the operator name that can be used to isolate the property using the less-than operator.
-
#object_type ⇒ String
The name of the object corresponding to the operator.
-
#operator_name ⇒ String
The name of the operator.
-
#type ⇒ String
The type of the operator.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryOperator
constructor
A new instance of QueryOperator.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryOperator
Returns a new instance of QueryOperator.
6268 6269 6270 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Display name of the operator
Corresponds to the JSON property displayName
6201 6202 6203 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6201 def display_name @display_name end |
#enum_values ⇒ Array<String>
Potential list of values for the opeatror field. This field is only filled
when we can safely enumerate all the possible values of this operator.
Corresponds to the JSON property enumValues
6207 6208 6209 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6207 def enum_values @enum_values end |
#greater_than_operator_name ⇒ String
Indicates the operator name that can be used to isolate the property using the
greater-than operator.
Corresponds to the JSON property greaterThanOperatorName
6213 6214 6215 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6213 def greater_than_operator_name @greater_than_operator_name end |
#is_facetable ⇒ Boolean Also known as: is_facetable?
Can this operator be used to get facets.
Corresponds to the JSON property isFacetable
6218 6219 6220 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6218 def is_facetable @is_facetable end |
#is_repeatable ⇒ Boolean Also known as: is_repeatable?
Indicates if multiple values can be set for this property.
Corresponds to the JSON property isRepeatable
6224 6225 6226 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6224 def is_repeatable @is_repeatable end |
#is_returnable ⇒ Boolean Also known as: is_returnable?
Will the property associated with this facet be returned as part of search
results.
Corresponds to the JSON property isReturnable
6231 6232 6233 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6231 def is_returnable @is_returnable end |
#is_sortable ⇒ Boolean Also known as: is_sortable?
Can this operator be used to sort results.
Corresponds to the JSON property isSortable
6237 6238 6239 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6237 def is_sortable @is_sortable end |
#is_suggestable ⇒ Boolean Also known as: is_suggestable?
Can get suggestions for this field.
Corresponds to the JSON property isSuggestable
6243 6244 6245 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6243 def is_suggestable @is_suggestable end |
#less_than_operator_name ⇒ String
Indicates the operator name that can be used to isolate the property using the
less-than operator.
Corresponds to the JSON property lessThanOperatorName
6250 6251 6252 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6250 def less_than_operator_name @less_than_operator_name end |
#object_type ⇒ String
The name of the object corresponding to the operator. This field is only
filled for schema-specific operators, and is unset for common operators.
Corresponds to the JSON property objectType
6256 6257 6258 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6256 def object_type @object_type end |
#operator_name ⇒ String
The name of the operator.
Corresponds to the JSON property operatorName
6261 6262 6263 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6261 def operator_name @operator_name end |
#type ⇒ String
The type of the operator.
Corresponds to the JSON property type
6266 6267 6268 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6266 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6273 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @enum_values = args[:enum_values] if args.key?(:enum_values) @greater_than_operator_name = args[:greater_than_operator_name] if args.key?(:greater_than_operator_name) @is_facetable = args[:is_facetable] if args.key?(:is_facetable) @is_repeatable = args[:is_repeatable] if args.key?(:is_repeatable) @is_returnable = args[:is_returnable] if args.key?(:is_returnable) @is_sortable = args[:is_sortable] if args.key?(:is_sortable) @is_suggestable = args[:is_suggestable] if args.key?(:is_suggestable) @less_than_operator_name = args[:less_than_operator_name] if args.key?(:less_than_operator_name) @object_type = args[:object_type] if args.key?(:object_type) @operator_name = args[:operator_name] if args.key?(:operator_name) @type = args[:type] if args.key?(:type) end |