Class: Google::Apis::CloudsearchV1::RequestOptions
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::RequestOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
Shared request options for all RPC methods.
Instance Attribute Summary collapse
-
#client_display_language_code ⇒ String
The BCP-47 language code, such as "pt" or "en".
-
#debug_options ⇒ Google::Apis::CloudsearchV1::DebugOptions
Shared request debug options for all cloudsearch RPC methods.
-
#language_code ⇒ String
The BCP-47 language code, such as "en-US" or "sr-Latn".
-
#search_application_id ⇒ String
The ID generated when you create a search application using the admin console.
-
#time_zone ⇒ String
Current user's time zone id, such as "America/Los_Angeles" or "Australia/ Sydney".
Instance Method Summary collapse
-
#initialize(**args) ⇒ RequestOptions
constructor
A new instance of RequestOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RequestOptions
Returns a new instance of RequestOptions.
6466 6467 6468 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_display_language_code ⇒ String
The BCP-47 language code, such as "pt" or "en". It represents the user's
preferred Display Language.
Corresponds to the JSON property clientDisplayLanguageCode
6432 6433 6434 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6432 def client_display_language_code @client_display_language_code end |
#debug_options ⇒ Google::Apis::CloudsearchV1::DebugOptions
Shared request debug options for all cloudsearch RPC methods.
Corresponds to the JSON property debugOptions
6437 6438 6439 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6437 def @debug_options end |
#language_code ⇒ String
The BCP-47 language code, such as "en-US" or "sr-Latn". For more information,
see http://www.unicode.org/reports/tr35/#Unicode_locale_identifier. For
translations. Set this field using the language set in browser or for the page.
In the event that the user's language preference is known, set this field to
the known user language. When specified, the documents in search results are
biased towards the specified language. The Suggest API uses this field as a
hint to make better third-party autocomplete predictions.
Corresponds to the JSON property languageCode
6448 6449 6450 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6448 def language_code @language_code end |
#search_application_id ⇒ String
The ID generated when you create a search application using the admin console.
Corresponds to the JSON property searchApplicationId
6454 6455 6456 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6454 def search_application_id @search_application_id end |
#time_zone ⇒ String
Current user's time zone id, such as "America/Los_Angeles" or "Australia/
Sydney". These IDs are defined by Unicode Common Locale Data Repository (CLDR)
project, and currently available in the file
timezone.xml.
This field is used to correctly interpret date and time queries. If this field
is not specified, the default time zone (UTC) is used.
Corresponds to the JSON property timeZone
6464 6465 6466 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6464 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6471 6472 6473 6474 6475 6476 6477 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6471 def update!(**args) @client_display_language_code = args[:client_display_language_code] if args.key?(:client_display_language_code) @debug_options = args[:debug_options] if args.key?(:debug_options) @language_code = args[:language_code] if args.key?(:language_code) @search_application_id = args[:search_application_id] if args.key?(:search_application_id) @time_zone = args[:time_zone] if args.key?(:time_zone) end |