Class: Google::Apis::CloudsearchV1::ResultDisplayField

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Display Fields for Search Results

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResultDisplayField

Returns a new instance of ResultDisplayField.



6620
6621
6622
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelString

The display label for the property. Corresponds to the JSON property label

Returns:

  • (String)


6606
6607
6608
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6606

def label
  @label
end

#operator_nameString

The operator name of the property. Corresponds to the JSON property operatorName

Returns:

  • (String)


6611
6612
6613
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6611

def operator_name
  @operator_name
end

#propertyGoogle::Apis::CloudsearchV1::NamedProperty

A typed name-value pair for structured data. The type of the value should be the same as the registered type for the name property in the object definition of objectType. Corresponds to the JSON property property



6618
6619
6620
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6618

def property
  @property
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6625
6626
6627
6628
6629
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6625

def update!(**args)
  @label = args[:label] if args.key?(:label)
  @operator_name = args[:operator_name] if args.key?(:operator_name)
  @property = args[:property] if args.key?(:property)
end