Class: Google::Apis::CloudsearchV1::SearchApplicationQueryStats
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::SearchApplicationQueryStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
Search application level query stats per date
Instance Attribute Summary collapse
-
#date ⇒ Google::Apis::CloudsearchV1::Date
Represents a whole calendar date, for example a date of birth.
-
#query_count_by_status ⇒ Array<Google::Apis::CloudsearchV1::QueryCountByStatus>
Corresponds to the JSON property
queryCountByStatus.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchApplicationQueryStats
constructor
A new instance of SearchApplicationQueryStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchApplicationQueryStats
Returns a new instance of SearchApplicationQueryStats.
6908 6909 6910 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6908 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date ⇒ Google::Apis::CloudsearchV1::Date
Represents a whole calendar date, for example a date of birth. The time of day
and time zone are either specified elsewhere or are not significant. The date
is relative to the Proleptic Gregorian Calendar. The date must be a valid calendar date
between the year 1 and 9999.
Corresponds to the JSON property date
6901 6902 6903 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6901 def date @date end |
#query_count_by_status ⇒ Array<Google::Apis::CloudsearchV1::QueryCountByStatus>
Corresponds to the JSON property queryCountByStatus
6906 6907 6908 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6906 def query_count_by_status @query_count_by_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6913 6914 6915 6916 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6913 def update!(**args) @date = args[:date] if args.key?(:date) @query_count_by_status = args[:query_count_by_status] if args.key?(:query_count_by_status) end |