Class: Google::Apis::CloudsearchV1::SearchApplicationUserStats
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::SearchApplicationUserStats
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Instance Attribute Summary collapse
-
#date ⇒ Google::Apis::CloudsearchV1::Date
Represents a whole calendar date, for example a date of birth.
-
#one_day_active_users_count ⇒ Fixnum
The count of unique active users in the past one day Corresponds to the JSON property
oneDayActiveUsersCount. -
#seven_days_active_users_count ⇒ Fixnum
The count of unique active users in the past seven days Corresponds to the JSON property
sevenDaysActiveUsersCount. -
#thirty_days_active_users_count ⇒ Fixnum
The count of unique active users in the past thirty days Corresponds to the JSON property
thirtyDaysActiveUsersCount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchApplicationUserStats
constructor
A new instance of SearchApplicationUserStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchApplicationUserStats
Returns a new instance of SearchApplicationUserStats.
6984 6985 6986 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6984 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date ⇒ Google::Apis::CloudsearchV1::Date
Represents a whole calendar date, for example a date of birth. The time of day
and time zone are either specified elsewhere or are not significant. The date
is relative to the Proleptic Gregorian Calendar. The date must be a valid calendar date
between the year 1 and 9999.
Corresponds to the JSON property date
6967 6968 6969 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6967 def date @date end |
#one_day_active_users_count ⇒ Fixnum
The count of unique active users in the past one day
Corresponds to the JSON property oneDayActiveUsersCount
6972 6973 6974 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6972 def one_day_active_users_count @one_day_active_users_count end |
#seven_days_active_users_count ⇒ Fixnum
The count of unique active users in the past seven days
Corresponds to the JSON property sevenDaysActiveUsersCount
6977 6978 6979 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6977 def seven_days_active_users_count @seven_days_active_users_count end |
#thirty_days_active_users_count ⇒ Fixnum
The count of unique active users in the past thirty days
Corresponds to the JSON property thirtyDaysActiveUsersCount
6982 6983 6984 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6982 def thirty_days_active_users_count @thirty_days_active_users_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6989 6990 6991 6992 6993 6994 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6989 def update!(**args) @date = args[:date] if args.key?(:date) @one_day_active_users_count = args[:one_day_active_users_count] if args.key?(:one_day_active_users_count) @seven_days_active_users_count = args[:seven_days_active_users_count] if args.key?(:seven_days_active_users_count) @thirty_days_active_users_count = args[:thirty_days_active_users_count] if args.key?(:thirty_days_active_users_count) end |