Class: Google::Apis::CloudsearchV1::SearchApplicationUserStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchApplicationUserStats

Returns a new instance of SearchApplicationUserStats.



6976
6977
6978
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dateGoogle::Apis::CloudsearchV1::Date

Represents a whole calendar date, for example a date of birth. The time of day and time zone are either specified elsewhere or are not significant. The date is relative to the Proleptic Gregorian Calendar. The date must be a valid calendar date between the year 1 and 9999. Corresponds to the JSON property date



6959
6960
6961
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6959

def date
  @date
end

#one_day_active_users_countFixnum

The count of unique active users in the past one day Corresponds to the JSON property oneDayActiveUsersCount

Returns:

  • (Fixnum)


6964
6965
6966
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6964

def one_day_active_users_count
  @one_day_active_users_count
end

#seven_days_active_users_countFixnum

The count of unique active users in the past seven days Corresponds to the JSON property sevenDaysActiveUsersCount

Returns:

  • (Fixnum)


6969
6970
6971
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6969

def seven_days_active_users_count
  @seven_days_active_users_count
end

#thirty_days_active_users_countFixnum

The count of unique active users in the past thirty days Corresponds to the JSON property thirtyDaysActiveUsersCount

Returns:

  • (Fixnum)


6974
6975
6976
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6974

def thirty_days_active_users_count
  @thirty_days_active_users_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6981
6982
6983
6984
6985
6986
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 6981

def update!(**args)
  @date = args[:date] if args.key?(:date)
  @one_day_active_users_count = args[:one_day_active_users_count] if args.key?(:one_day_active_users_count)
  @seven_days_active_users_count = args[:seven_days_active_users_count] if args.key?(:seven_days_active_users_count)
  @thirty_days_active_users_count = args[:thirty_days_active_users_count] if args.key?(:thirty_days_active_users_count)
end