Class: Google::Apis::CloudsearchV1::SearchRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::SearchRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
The search API request. NEXT ID: 25
Instance Attribute Summary collapse
-
#context_attributes ⇒ Array<Google::Apis::CloudsearchV1::ContextAttribute>
Context attributes for the request which will be used to adjust ranking of search results.
-
#data_source_restrictions ⇒ Array<Google::Apis::CloudsearchV1::DataSourceRestriction>
The sources to use for querying.
-
#facet_options ⇒ Array<Google::Apis::CloudsearchV1::FacetOptions>
Corresponds to the JSON property
facetOptions. -
#page_size ⇒ Fixnum
Maximum number of search results to return in one page.
-
#query ⇒ String
The raw query string.
-
#query_interpretation_options ⇒ Google::Apis::CloudsearchV1::QueryInterpretationOptions
Options to interpret user query.
-
#request_options ⇒ Google::Apis::CloudsearchV1::RequestOptions
Shared request options for all RPC methods.
-
#sort_options ⇒ Google::Apis::CloudsearchV1::SortOptions
The options for sorting the search results Corresponds to the JSON property
sortOptions. -
#start ⇒ Fixnum
Starting index of the results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchRequest
constructor
A new instance of SearchRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchRequest
Returns a new instance of SearchRequest.
7122 7123 7124 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_attributes ⇒ Array<Google::Apis::CloudsearchV1::ContextAttribute>
Context attributes for the request which will be used to adjust ranking of
search results. The maximum number of elements is 10.
Corresponds to the JSON property contextAttributes
7076 7077 7078 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7076 def context_attributes @context_attributes end |
#data_source_restrictions ⇒ Array<Google::Apis::CloudsearchV1::DataSourceRestriction>
The sources to use for querying. If not specified, all data sources from the
current search application are used.
Corresponds to the JSON property dataSourceRestrictions
7082 7083 7084 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7082 def data_source_restrictions @data_source_restrictions end |
#facet_options ⇒ Array<Google::Apis::CloudsearchV1::FacetOptions>
Corresponds to the JSON property facetOptions
7087 7088 7089 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7087 def @facet_options end |
#page_size ⇒ Fixnum
Maximum number of search results to return in one page. Valid values are
between 1 and 100, inclusive. Default value is 10. Minimum value is 50 when
results beyond 2000 are requested.
Corresponds to the JSON property pageSize
7094 7095 7096 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7094 def page_size @page_size end |
#query ⇒ String
The raw query string. See supported search operators in the Narrow your
search with operators
Corresponds to the JSON property query
7100 7101 7102 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7100 def query @query end |
#query_interpretation_options ⇒ Google::Apis::CloudsearchV1::QueryInterpretationOptions
Options to interpret user query.
Corresponds to the JSON property queryInterpretationOptions
7105 7106 7107 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7105 def @query_interpretation_options end |
#request_options ⇒ Google::Apis::CloudsearchV1::RequestOptions
Shared request options for all RPC methods.
Corresponds to the JSON property requestOptions
7110 7111 7112 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7110 def @request_options end |
#sort_options ⇒ Google::Apis::CloudsearchV1::SortOptions
The options for sorting the search results
Corresponds to the JSON property sortOptions
7115 7116 7117 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7115 def @sort_options end |
#start ⇒ Fixnum
Starting index of the results.
Corresponds to the JSON property start
7120 7121 7122 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7120 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7127 def update!(**args) @context_attributes = args[:context_attributes] if args.key?(:context_attributes) @data_source_restrictions = args[:data_source_restrictions] if args.key?(:data_source_restrictions) @facet_options = args[:facet_options] if args.key?(:facet_options) @page_size = args[:page_size] if args.key?(:page_size) @query = args[:query] if args.key?(:query) @query_interpretation_options = args[:query_interpretation_options] if args.key?(:query_interpretation_options) @request_options = args[:request_options] if args.key?(:request_options) @sort_options = args[:sort_options] if args.key?(:sort_options) @start = args[:start] if args.key?(:start) end |