Class: Google::Apis::CloudsearchV1::SearchResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb

Overview

Results containing indexed information for a document. Next ID: 16

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchResult

Returns a new instance of SearchResult.



7260
7261
7262
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clustered_resultsArray<Google::Apis::CloudsearchV1::SearchResult>

If source is clustered, provide list of clustered results. There will only be one level of clustered results. If current source is not enabled for clustering, this field will be empty. Corresponds to the JSON property clusteredResults



7231
7232
7233
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7231

def clustered_results
  @clustered_results
end

#debug_infoGoogle::Apis::CloudsearchV1::ResultDebugInfo

Debugging information about the result. Corresponds to the JSON property debugInfo



7236
7237
7238
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7236

def debug_info
  @debug_info
end

#metadataGoogle::Apis::CloudsearchV1::Metadata

Metadata of a matched search result. Corresponds to the JSON property metadata



7241
7242
7243
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7241

def 
  @metadata
end

#snippetGoogle::Apis::CloudsearchV1::Snippet

Snippet of the search result, which summarizes the content of the resulting page. Corresponds to the JSON property snippet



7247
7248
7249
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7247

def snippet
  @snippet
end

#titleString

Title of the search result. Corresponds to the JSON property title

Returns:

  • (String)


7252
7253
7254
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7252

def title
  @title
end

#urlString

The URL of the search result. The URL contains a Google redirect to the actual item. This URL is signed and shouldn't be changed. Corresponds to the JSON property url

Returns:

  • (String)


7258
7259
7260
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7258

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7265
7266
7267
7268
7269
7270
7271
7272
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7265

def update!(**args)
  @clustered_results = args[:clustered_results] if args.key?(:clustered_results)
  @debug_info = args[:debug_info] if args.key?(:debug_info)
  @metadata = args[:metadata] if args.key?(:metadata)
  @snippet = args[:snippet] if args.key?(:snippet)
  @title = args[:title] if args.key?(:title)
  @url = args[:url] if args.key?(:url)
end