Class: Google::Apis::CloudsearchV1::SourceConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::SourceConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
Configurations for a source while processing a Search or Suggest request.
Instance Attribute Summary collapse
-
#crowding_config ⇒ Google::Apis::CloudsearchV1::SourceCrowdingConfig
Set search results crowding limits.
-
#scoring_config ⇒ Google::Apis::CloudsearchV1::SourceScoringConfig
Set the scoring configuration.
-
#source ⇒ Google::Apis::CloudsearchV1::Source
Defines sources for the suggest/search APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceConfig
constructor
A new instance of SourceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceConfig
Returns a new instance of SourceConfig.
7377 7378 7379 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crowding_config ⇒ Google::Apis::CloudsearchV1::SourceCrowdingConfig
Set search results crowding limits. Crowding is a situation in which multiple
results from the same source or host "crowd out" other results, diminishing
the quality of search for users. To foster better search quality and source
diversity in search results, you can set a condition to reduce repetitive
results by source.
Corresponds to the JSON property crowdingConfig
7364 7365 7366 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7364 def crowding_config @crowding_config end |
#scoring_config ⇒ Google::Apis::CloudsearchV1::SourceScoringConfig
Set the scoring configuration. This allows modifying the ranking of results
for a source.
Corresponds to the JSON property scoringConfig
7370 7371 7372 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7370 def scoring_config @scoring_config end |
#source ⇒ Google::Apis::CloudsearchV1::Source
Defines sources for the suggest/search APIs.
Corresponds to the JSON property source
7375 7376 7377 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7375 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7382 7383 7384 7385 7386 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7382 def update!(**args) @crowding_config = args[:crowding_config] if args.key?(:crowding_config) @scoring_config = args[:scoring_config] if args.key?(:scoring_config) @source = args[:source] if args.key?(:source) end |