Class: Google::Apis::CloudsearchV1::TimestampPropertyOptions
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::TimestampPropertyOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
The options for timestamp properties.
Instance Attribute Summary collapse
-
#operator_options ⇒ Google::Apis::CloudsearchV1::TimestampOperatorOptions
Used to provide a search operator for timestamp properties.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimestampPropertyOptions
constructor
A new instance of TimestampPropertyOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimestampPropertyOptions
Returns a new instance of TimestampPropertyOptions.
7919 7920 7921 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operator_options ⇒ Google::Apis::CloudsearchV1::TimestampOperatorOptions
Used to provide a search operator for timestamp properties. This is optional.
Search operators let users restrict the query to specific fields relevant to
the type of item being searched.
Corresponds to the JSON property operatorOptions
7917 7918 7919 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7917 def @operator_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7924 7925 7926 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 7924 def update!(**args) @operator_options = args[:operator_options] if args.key?(:operator_options) end |