Class: Google::Apis::CloudsearchV1::Value
- Inherits:
-
Object
- Object
- Google::Apis::CloudsearchV1::Value
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudsearch_v1/classes.rb,
lib/google/apis/cloudsearch_v1/representations.rb,
lib/google/apis/cloudsearch_v1/representations.rb
Overview
Definition of a single value with generic type.
Instance Attribute Summary collapse
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
Corresponds to the JSON property
booleanValue. -
#date_value ⇒ Google::Apis::CloudsearchV1::Date
Represents a whole calendar date, for example a date of birth.
-
#double_value ⇒ Float
Corresponds to the JSON property
doubleValue. -
#integer_value ⇒ Fixnum
Corresponds to the JSON property
integerValue. -
#string_value ⇒ String
Corresponds to the JSON property
stringValue. -
#timestamp_value ⇒ String
Corresponds to the JSON property
timestampValue.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Value
constructor
A new instance of Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Value
Returns a new instance of Value.
8172 8173 8174 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_value ⇒ Boolean Also known as: boolean_value?
Corresponds to the JSON property booleanValue
8140 8141 8142 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8140 def boolean_value @boolean_value end |
#date_value ⇒ Google::Apis::CloudsearchV1::Date
Represents a whole calendar date, for example a date of birth. The time of day
and time zone are either specified elsewhere or are not significant. The date
is relative to the Proleptic Gregorian Calendar. The date must be a valid calendar date
between the year 1 and 9999.
Corresponds to the JSON property dateValue
8150 8151 8152 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8150 def date_value @date_value end |
#double_value ⇒ Float
Corresponds to the JSON property doubleValue
8155 8156 8157 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8155 def double_value @double_value end |
#integer_value ⇒ Fixnum
Corresponds to the JSON property integerValue
8160 8161 8162 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8160 def integer_value @integer_value end |
#string_value ⇒ String
Corresponds to the JSON property stringValue
8165 8166 8167 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8165 def string_value @string_value end |
#timestamp_value ⇒ String
Corresponds to the JSON property timestampValue
8170 8171 8172 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8170 def @timestamp_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/google/apis/cloudsearch_v1/classes.rb', line 8177 def update!(**args) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @date_value = args[:date_value] if args.key?(:date_value) @double_value = args[:double_value] if args.key?(:double_value) @integer_value = args[:integer_value] if args.key?(:integer_value) @string_value = args[:string_value] if args.key?(:string_value) @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value) end |